Name:       fish
Version:    3.6.4
Release:    %mkrel 1
Summary:    Smart and user-friendly command line shell
Group:      Shells
License:    GPLv2
Url:        https://fishshell.com/
Source:     https://github.com/fish-shell/fish-shell/releases/download/%{version}/fish-%{version}.tar.xz
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pcre2-devel
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  doxygen
BuildRequires:  intltool
BuildRequires:  gettext-devel
# fish's 'math' command requires bc
Requires:   bc
# for fish_update_completions script
Recommends:   man-db
Recommends:   python-backports-lzma

%description
fish is a fully-equipped command line shell (like bash or zsh) that is smart
and user-friendly. fish supports powerful features like syntax highlighting,
autosuggestions, and tab completions that just work, with nothing to learn
or configure.

%prep
%autosetup

#build against system pcre2
rm -rf pcre2*

%build
%cmake -GNinja
%cmake_build

%install
%cmake_install

#create conf.d
mkdir -p %{buildroot}%{_sysconfdir}/fish/conf.d

# remove unneeded pkgconfig .pc file
rm -rf %{buildroot}%{_datadir}/pkgconfig/fish.pc

rm -rf %{buildroot}%{_docdir}/%{name}/.buildinfo

%find_lang %{name}

%post
%{_rpm_helper_dir}/add-shell %{name} $1 %{_bindir}/fish

%postun
%{_rpm_helper_dir}/del-shell %{name} $1 %{_bindir}/fish

%files -f %{name}.lang
%doc CONTRIBUTING.rst README.rst CHANGELOG.rst
%doc user_doc/html/*
%dir %{_sysconfdir}/fish/
%dir %{_sysconfdir}/fish/conf.d/
%config(noreplace) %{_sysconfdir}/fish/config.fish
%{_bindir}/fish
%{_bindir}/fish_indent
%{_bindir}/fish_key_reader
%{_datadir}/%{name}/
%{_datadir}/applications/fish.desktop
%{_datadir}/pixmaps/fish.png
%{_mandir}/man1/fish.1*
%{_mandir}/man1/fish_indent.1*
%{_mandir}/man1/fish_key_reader.1*


%changelog
* Fri Dec 08 2023 kekepower <kekepower> 3.6.4-1.mga9
+ Revision: 2015529
- Update to version 3.6.4 to fix CVE-2023-49284 (mga#32603)

* Sun Apr 16 2023 kekepower <kekepower> 3.6.1-1.mga9
+ Revision: 1953232
- Update to version 3.6.1

* Thu Jan 19 2023 kekepower <kekepower> 3.6.0-1.mga9
+ Revision: 1934402
- Update to version 3.6.0

* Thu Aug 18 2022 neoclust <neoclust> 3.5.1-1.mga9
+ Revision: 1878521
- New version 3.5.1

* Sat Jul 16 2022 guillomovitch <guillomovitch> 3.5.0-1.mga9
+ Revision: 1869188
- new version 3.5.0

* Sat Apr 02 2022 guillomovitch <guillomovitch> 3.4.1-1.mga9
+ Revision: 1841001
- new version 3.4.1

* Tue Mar 29 2022 umeabot <umeabot> 3.3.1-2.mga9
+ Revision: 1833057
- Mageia 9 Mass Rebuild

* Tue Jul 13 2021 guillomovitch <guillomovitch> 3.3.1-1.mga9
+ Revision: 1735940
- new version 3.3.1

* Sun Jul 04 2021 joequant <joequant> 3.3.0-1.mga9
+ Revision: 1734688
- update to 3.3.0

* Sun Mar 28 2021 guillomovitch <guillomovitch> 3.2.1-1.mga9
+ Revision: 1711534
- new version 3.2.1

* Mon Jul 20 2020 wally <wally> 3.1.2-2.mga8
+ Revision: 1607501
- build with new cmake macros

* Sun May 03 2020 kekepower <kekepower> 3.1.2-1.mga8
+ Revision: 1578455
- Update to version 3.1.2

* Fri Feb 14 2020 umeabot <umeabot> 3.1.0-2.mga8
+ Revision: 1523096
- Mageia 8 Mass Rebuild

* Fri Feb 14 2020 guillomovitch <guillomovitch> 3.1.0-1.mga8
+ Revision: 1521552
- new version 3.1.0
+ wally <wally>
- build with new cmake macros

* Tue Feb 19 2019 kekepower <kekepower> 3.0.2-1.mga7
+ Revision: 1368624
- Update to version 3.0.2

* Tue Feb 12 2019 kekepower <kekepower> 3.0.1-1.mga7
+ Revision: 1366054
- Update to version 3.0.1

* Mon Dec 31 2018 kekepower <kekepower> 3.0.0-1.mga7
+ Revision: 1347593
- Update to version 3.0.0

* Sun Sep 23 2018 umeabot <umeabot> 2.7.1-2.mga7
+ Revision: 1297707
- Mageia 7 Mass Rebuild

* Sun Jan 21 2018 guillomovitch <guillomovitch> 2.7.1-1.mga7
+ Revision: 1195497
- new version 2.7.1

* Sat Nov 25 2017 guillomovitch <guillomovitch> 2.7.0-1.mga7
+ Revision: 1179219
- new version 2.7.0

* Tue Jul 18 2017 guillomovitch <guillomovitch> 2.6.0-1.mga7
+ Revision: 1124769
- new version 2.6.0

* Mon Jan 16 2017 guillomovitch <guillomovitch> 2.4.0-1.mga6
+ Revision: 1081959
- new version 2.4.0

* Sat Sep 03 2016 wally <wally> 2.3.1-1.mga6
+ Revision: 1049939
- new version 2.3.1
- add recommends for fish_update_completions script
  * man-db
  * python-backports-lzma

* Mon Aug 22 2016 wally <wally> 2.2.0-4.mga6
+ Revision: 1047722
- remove unneeded pkgconfig .pc file
- own /etc/fish/ directory
- update summary and description
- require bc

* Sun Aug 21 2016 wally <wally> 2.2.0-3.mga6
+ Revision: 1047584
- add fish to /etc/shells (mga#19224)

* Thu Feb 11 2016 umeabot <umeabot> 2.2.0-2.mga6
+ Revision: 953941
- Mageia 6 Mass Rebuild

* Sat Jul 25 2015 guillomovitch <guillomovitch> 2.2.0-1.mga6
+ Revision: 857103
- new version 2.2.0

* Wed Oct 15 2014 umeabot <umeabot> 2.1.1-2.mga5
+ Revision: 745402
- Second Mageia 5 Mass Rebuild

* Mon Oct 06 2014 luigiwalser <luigiwalser> 2.1.1-1.mga5
+ Revision: 737092
- 2.1.1 (fixes multiple security issues, mga#13984)

* Tue Sep 16 2014 umeabot <umeabot> 2.1.0-2.mga5
+ Revision: 679213
- Mageia 5 Mass Rebuild

* Thu Nov 28 2013 guillomovitch <guillomovitch> 2.1.0-1.mga4
+ Revision: 553829
- imported package fish

